@@ -1,7 +1,6 @@
 import requests
 
 from exceptions import *
-from signed_request import parse_signed_request
 
 try:
     import simplejson as json
@@ -10,23 +9,15 @@ except ImportError:
 
 class GraphAPI(object):
 
-    def __init__(self, oauth_token=None, signed_request=None, app_secret=None):
-        """Initialize GraphAPI with an oauth_token, signed request or neither.
-
-        If signed_request is given along with app_secret, oauth_token will be
-        extracted automatically from the signed_request.
+    def __init__(self, oauth_token=False):
+        """
+        Initialize GraphAPI with an OAuth token, a signed request or neither.
 
         Arguments:
-        oauth_token -- OAuth 2.0 token
-        signed_request -- raw signed_request taken from POST (optional)
-        app_secret -- Application's app_secret required to parse signed_request (optional)
+        oauth_token -- A string describing an OAuth token.
+        signed_request -- A SignedRequest instance (see facepy.signed_request.SignedRequest).
         """
-
-        if not oauth_token and signed_request and app_secret:
-            sr = parse_signed_request(signed_request, app_secret)
-            self.oauth_token = sr.get("oauth_token", None)
-        else:
-            self.oauth_token = oauth_token
+        self.oauth_token = oauth_token
 
     def get(self, path='', page=False, **options):
         """
@@ -110,13 +101,31 @@ class GraphAPI(object):
         url -- A string describing the URL.
         data -- A dictionary of HTTP GET parameters (for GET requests) or POST data (for POST requests).
 
-        Returns a pair (obj, next_url) where obj is the object returned from the graph API (parsed 
+        Returns a pair (obj, next_url) where obj is the object returned from the graph API (parsed
         into a python object) and next_url is the URL for more results or None if this is the last
         page of results.
         """
+        def strip_filelike(input):
+            files = {}
+
+            for key, value in input.iteritems():
+                if hasattr(value, 'read'): # it quacks like a file!
+                    files[key] = input[key]
+
+            for key in files.iterkeys():
+                input.pop(key)
+
+            if not files:
+                files = None
+
+            return files
 
         if method in ['GET', 'DELETE']:
             response = requests.request(method, url, params=data)
+        elif method in ['POST', 'PUT']:
+            files = strip_filelike(data)
+
+            response = requests.request(method, url, data=data, files=files)
         else:
             response = requests.request(method, url, data=data)
 
